beamviz
=======

Installation
------------

    pip3 install beamviz

Use
----

    beamviz my.egsinp --watch

Then 

- install http://www.openscad.org/
- open the SCAD file with OpenSCAD
- under Design, choose the Automatic Reload and Preview
